/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.processes.cdimport;

import java.io.File;
import java.util.Collection;
import java.util.Iterator;
import java.util.Vector;

import net.sf.dc.console.da.ImportCDDialog;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.core.modules.DCModule;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.messages.Messages;
import net.sf.dc.messages.MessagesWriter;
import net.sf.dc.resources.DCMessages;
import net.sf.dc.wf.WorkFlow;
import net.sf.ext.util.DirectoryReader;
import net.sf.ext.util.Resources;

/**
 * Imports data from a CD (or harddisk) location into the insert table
 * of the owner module
 * 
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.9
 */
public abstract class ImportCDProcess extends Thread {

    protected static final WorkFlow wf = new WorkFlow();

    private final ImportCDDialog ui;
    
    protected String sourceDir = "";
    protected boolean confirmDirs = false;
    protected boolean recursiveDirs = true;
    protected String cdName = "";
    
    private boolean keepOnRunning = true;

    /**
     * Initializes (but does  not run) the CD import process
     * @param ui used for displaying the progress
     * @param sourceDir directory which is used as source for the
     *        import
     * @param confirmDirs indicates whether for each directory
     *        confirmation should be asked if the underlying data
     *        of this directory should be read or not.
     * @param nameOfCD cd name (used as the location name)
     */    
    public ImportCDProcess( ImportCDDialog ui, 
                            String sourceDir,
                            boolean confirmDirs,
                            boolean recursiveDirs,
                            String cdName) {
    	this.ui = ui;
        
        if (!sourceDir.endsWith(File.separator)) {
            this.sourceDir = sourceDir;
        } else {
            this.sourceDir = sourceDir.substring(0, sourceDir.length() -1);
        }
        this.confirmDirs = confirmDirs;
        this.recursiveDirs = recursiveDirs;
        this.cdName = cdName;
    }
    
    /**
     * Starts the CD Import process
     */
    public void run() {
        try {
            ui.addMessage(Resources.getText(DCMessages.msgImportStarts));
            ui.addMessage(Resources.getText(DCMessages.msgImportReadingDirs));
            Vector filesAndDirs = DirectoryReader.read( sourceDir, 
                                                        confirmDirs,
                                                        recursiveDirs,
                                                        true,
                                                        getExtensions(),
                                                        false);
            writeOutput(filesAndDirs);
        } catch (Exception exp) {
            exp.printStackTrace();
            ui.addMessage(DCMessages.msgProcessCrash);
            MessagesWriter._useLogFile = true;
            Messages.add(exp);
            new MessageBox(Resources.getText(DCMessages.msgProcessCrash), 
                           MessageBox._ERROR);
        }
    }   
    
    public abstract String[] getExtensions();
    
    protected int getFileSize(String path) {
        File file = new File(path);
        
        long fileSize = 0;
        if (file.isDirectory()) {
            try {
                Collection files = DirectoryReader.read(path, false, true, false, null, false);
                
                for (Iterator iter = files.iterator(); iter.hasNext(); ) {
                    File folderFile = new File(iter.next().toString());
                    fileSize += folderFile.length();
                }
            } catch (Exception exp) {
                Messages.add(exp);
            }
        } else {
            fileSize = file.length();
        }
        return Math.round(((float) fileSize) / 1024f);
    }
    
    private void finish() {
        ui.addMessage(Resources.getText(DCMessages.msgImportCompleted));
    }
    
    public void cancel() {
    	keepOnRunning = false;
        finish();
    }
    
    /**
     * Parses the source files for information and adds the parsed
     * information to the insert table of the owner module.
     * @param filenames files to be parsed
     */
    public void writeOutput(Collection filenames) {
        try {
            ui.addMessage(Resources.getText(DCMessages.msgImportFoundXResults,
                          "" + filenames.size()));
            ui.initProgressBar(filenames.size());
            int counter = 1;
            for (   Iterator iter = filenames.iterator(); iter.hasNext() 
                    && keepOnRunning; counter++) {
                
                String sFilename = iter.next().toString();
                ui.addMessage(Resources.getText(DCMessages.msgProcessingFileX, sFilename));
                DCObject dco = parseInformation(sFilename);
                
                if (dco != null) {
                    DCModule module = DCModules.getModule(getModule());
                    module.getInsertPanel().addObject(dco);
                }
                try {
                	sleep(100);
                } catch (Exception ignore) {}
                
                ui.updateProgressBar(counter);
            }
        } catch (Exception exp) {
            new MessageBox(ui, Resources.getText(DCMessages.msgProcessCrash), 
                           MessageBox._ERROR);
            Messages.add(exp);
        } finally {
        	filenames.clear();
        	filenames = null;
            ui.addMessage(Resources.getText(DCMessages.msgImportStops));
            ui.allowActions();
        }
    }   
    
    protected String getName(String file) {
        String name = file;
        int index = name.lastIndexOf(File.separator);
        if (index >=0) {
            name = name.substring(index + 1, name.length());
            
            index = name.lastIndexOf(".");
            if (index > 0 && index > name.length() - 5) {
                name = name.substring(0, index);
            }
            
            name = name.replaceAll("\\.", " ");
            name = name.replaceAll("_", " ");
            name = name.replaceAll("-", " ");                
        }   
        return name;
    }
    
    /**
     * Parses the file for its information. Needs to be implemented
     * by the extending classes 
     * @param sFilename file to be parsed
     */
    protected abstract DCObject parseInformation(String sFilename);
    
    /**
     * The UI class which will be updated with the results of the import 
     */
    protected abstract int getModule();
}
